package com.sun.xml.internal.ws.server.provider;

import com.sun.istack.internal.NotNull;
import com.sun.xml.internal.ws.api.WSBinding;
import com.sun.xml.internal.ws.api.model.wsdl.WSDLPort;
import com.sun.xml.internal.ws.api.pipe.ThrowableContainerPropertySet;
import java.util.logging.Level;
import com.sun.xml.internal.ws.api.pipe.NextAction;
import com.sun.xml.internal.ws.api.message.Packet;
import com.sun.xml.internal.ws.api.server.Invoker;
import java.util.logging.Logger;

public class SyncProviderInvokerTube<T> extends ProviderInvokerTube<T>
{
    private static final Logger LOGGER;
    
    public SyncProviderInvokerTube(Invoker invoker, ProviderArgumentsBuilder<T> argsBuilder) {
        super(invoker, argsBuilder);
    }
    
    public NextAction processRequest(Packet request) {
        WSDLPort port = this.getEndpoint().getPort();
        WSBinding binding = this.getEndpoint().getBinding();
        T param = this.argsBuilder.getParameter(request);
        SyncProviderInvokerTube.LOGGER.fine("Invoking Provider Endpoint");
        T returnValue;
        try {
            returnValue = this.getInvoker(request).invokeProvider(request, param);
        }
        catch (Exception e) {
            SyncProviderInvokerTube.LOGGER.log(Level.SEVERE, e.getMessage(), e);
            Packet response = this.argsBuilder.getResponse(request, e, port, binding);
            return this.doReturnWith(response);
        }
        if (returnValue == null && request.transportBackChannel != null) {
            request.transportBackChannel.close();
        }
        Packet response2 = this.argsBuilder.getResponse(request, returnValue, port, binding);
        ThrowableContainerPropertySet tc = (ThrowableContainerPropertySet)response2.getSatellite(ThrowableContainerPropertySet.class);
        Throwable t = (tc != null) ? tc.getThrowable() : null;
        return (t != null) ? this.doThrow(response2, t) : this.doReturnWith(response2);
    }
    
    @NotNull
    public NextAction processResponse(@NotNull Packet response) {
        return this.doReturnWith(response);
    }
    
    @NotNull
    public NextAction processException(@NotNull Throwable t) {
        return this.doThrow(t);
    }
    
    static {
        LOGGER = Logger.getLogger("com.sun.xml.internal.ws.server.SyncProviderInvokerTube");
    }
}
